from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Directory, String, Boolean, Int

Hap_Py_V0_1_0 = CommandToolBuilder(tool="hap.py", base_command=["hap.py"], inputs=[ToolInput(tag="in_reference", input_type=File(optional=True), prefix="--reference", doc=InputDocumentation(doc="Specify a reference file.")), ToolInput(tag="in_report_prefix", input_type=File(optional=True), prefix="--report-prefix", doc=InputDocumentation(doc="Filename prefix for report output.")), ToolInput(tag="in_scratch_prefix", input_type=Directory(optional=True), prefix="--scratch-prefix", doc=InputDocumentation(doc="Directory for scratch files.")), ToolInput(tag="in_keep_scratch", input_type=File(optional=True), prefix="--keep-scratch", doc=InputDocumentation(doc="Filename prefix for scratch report output.")), ToolInput(tag="in_type", input_type=String(optional=True), prefix="--type", doc=InputDocumentation(doc="Annotation format in input VCF file.")), ToolInput(tag="in_false_positives", input_type=File(optional=True), prefix="--false-positives", doc=InputDocumentation(doc="False positive / confident call regions (.bed or\n.bed.gz). Calls outside these regions will be labelled\nas UNK.")), ToolInput(tag="in_stratification", input_type=File(optional=True), prefix="--stratification", doc=InputDocumentation(doc="Stratification file list (TSV format -- first column\nis region name, second column is file name).")), ToolInput(tag="in_stratification_region", input_type=String(optional=True), prefix="--stratification-region", doc=InputDocumentation(doc="Add single stratification region, e.g.\n--stratification-region TEST:test.bed")), ToolInput(tag="in_stratification_fix_chr", input_type=Boolean(optional=True), prefix="--stratification-fixchr", doc=InputDocumentation(doc="Add chr prefix to stratification files if necessary")), ToolInput(tag="in_write_vcf", input_type=Boolean(optional=True), prefix="--write-vcf", doc=InputDocumentation(doc="Write an annotated VCF.")), ToolInput(tag="in_write_counts", input_type=Boolean(optional=True), prefix="--write-counts", doc=InputDocumentation(doc="Write advanced counts and metrics.")), ToolInput(tag="in_no_write_counts", input_type=Boolean(optional=True), prefix="--no-write-counts", doc=InputDocumentation(doc="Do not write advanced counts and metrics.")), ToolInput(tag="in_output_vtc", input_type=Boolean(optional=True), prefix="--output-vtc", doc=InputDocumentation(doc="Write VTC field in the final VCF which gives the\ncounts each position has contributed to.")), ToolInput(tag="in_preserve_info", input_type=Boolean(optional=True), prefix="--preserve-info", doc=InputDocumentation(doc="When using XCMP, preserve and merge the INFO fields in\ntruth and query. Useful for ROC computation.")), ToolInput(tag="in_roc", input_type=String(optional=True), prefix="--roc", doc=InputDocumentation(doc="Select a feature to produce a ROC on (INFO feature,\nQUAL, GQX, ...).")), ToolInput(tag="in_no_roc", input_type=Boolean(optional=True), prefix="--no-roc", doc=InputDocumentation(doc="Disable ROC computation and only output summary\nstatistics for more concise output.")), ToolInput(tag="in_roc_regions", input_type=String(optional=True), prefix="--roc-regions", doc=InputDocumentation(doc="Select a list of regions to compute ROCs in. By\ndefault, only the '*' region will produce ROC output\n(aggregate variant counts).")), ToolInput(tag="in_roc_filter", input_type=String(optional=True), prefix="--roc-filter", doc=InputDocumentation(doc="Select a filter to ignore when making ROCs.")), ToolInput(tag="in_roc_delta", input_type=String(optional=True), prefix="--roc-delta", doc=InputDocumentation(doc="Minimum spacing between ROC QQ levels.")), ToolInput(tag="in_ci_alpha", input_type=String(optional=True), prefix="--ci-alpha", doc=InputDocumentation(doc="Confidence level for Jeffrey's CI for recall,\nprecision and fraction of non-assessed calls.")), ToolInput(tag="in_no_json", input_type=File(optional=True), prefix="--no-json", doc=InputDocumentation(doc="Disable JSON file output.")), ToolInput(tag="in_location", input_type=String(optional=True), prefix="--location", doc=InputDocumentation(doc="Comma-separated list of locations [use naming after\npreprocessing], when not specified will use whole VCF.")), ToolInput(tag="in_pass_only", input_type=Boolean(optional=True), prefix="--pass-only", doc=InputDocumentation(doc="Keep only PASS variants.")), ToolInput(tag="in_filters_only", input_type=String(optional=True), prefix="--filters-only", doc=InputDocumentation(doc="Specify a comma-separated list of filters to apply (by\ndefault all filters are ignored / passed on.")), ToolInput(tag="in_restrict_regions", input_type=File(optional=True), prefix="--restrict-regions", doc=InputDocumentation(doc="Restrict analysis to given (sparse) regions (using -R\nin bcftools).")), ToolInput(tag="in_target_regions", input_type=File(optional=True), prefix="--target-regions", doc=InputDocumentation(doc="Restrict analysis to given (dense) regions (using -T\nin bcftools).")), ToolInput(tag="in_left_shift", input_type=Boolean(optional=True), prefix="--leftshift", doc=InputDocumentation(doc="Left-shift variants safely.")), ToolInput(tag="in_no_left_shift", input_type=Boolean(optional=True), prefix="--no-leftshift", doc=InputDocumentation(doc="Do not left-shift variants safely.")), ToolInput(tag="in_decompose", input_type=Boolean(optional=True), prefix="--decompose", doc=InputDocumentation(doc="Decompose variants into primitives. This results in\nmore granular counts.")), ToolInput(tag="in_no_decompose", input_type=Boolean(optional=True), prefix="--no-decompose", doc=InputDocumentation(doc="Do not decompose variants into primitives.")), ToolInput(tag="in_bcf_tools_norm", input_type=Boolean(optional=True), prefix="--bcftools-norm", doc=InputDocumentation(doc="Enable preprocessing through bcftools norm -c x -D\n(requires external preprocessing to be switched on).")), ToolInput(tag="in_fix_chr", input_type=Boolean(optional=True), prefix="--fixchr", doc=InputDocumentation(doc="Add chr prefix to VCF records where necessary\n(default: auto, attempt to match reference).")), ToolInput(tag="in_no_fix_chr", input_type=Boolean(optional=True), prefix="--no-fixchr", doc=InputDocumentation(doc="Do not add chr prefix to VCF records (default: auto,\nattempt to match reference).")), ToolInput(tag="in_bcf", input_type=Boolean(optional=True), prefix="--bcf", doc=InputDocumentation(doc="Use BCF internally. This is the default when the input\nfile is in BCF format already. Using BCF can speed up\ntemp file access, but may fail for VCF files that have\nbroken headers or records that don't comply with the\nheader.")), ToolInput(tag="in_somatic", input_type=Boolean(optional=True), prefix="--somatic", doc=InputDocumentation(doc="Assume the input file is a somatic call file and\nsquash all columns into one, putting all FORMATs into\nINFO + use half genotypes (see also --set-gt). This\nwill replace all sample columns and replace them with\na single one.")), ToolInput(tag="in_set_gt", input_type=String(optional=True), prefix="--set-gt", doc=InputDocumentation(doc="This is used to treat Strelka somatic files Possible\nvalues for this parameter: half / hemi / het / hom /\nhalf to assign one of the following genotypes to the\nresulting sample: 1 | 0/1 | 1/1 | ./1. This will\nreplace all sample columns and replace them with a\nsingle one.")), ToolInput(tag="in_filter_non_ref", input_type=Boolean(optional=True), prefix="--filter-nonref", doc=InputDocumentation(doc="Remove any variants genotyped as <NON_REF>.")), ToolInput(tag="in_convert_gvc_f_to_vcf", input_type=Boolean(optional=True), prefix="--convert-gvcf-to-vcf", doc=InputDocumentation(doc="Convert the input set from genome VCF format to a VCF\nbefore processing.")), ToolInput(tag="in_gender", input_type=String(optional=True), prefix="--gender", doc=InputDocumentation(doc="Specify sex. This determines how haploid calls on chrX\nget treated: for male samples, all non-ref calls (in\nthe truthset only when running through hap.py) are\ngiven a 1/1 genotype.")), ToolInput(tag="in_convert_gvc_f_truth", input_type=Boolean(optional=True), prefix="--convert-gvcf-truth", doc=InputDocumentation(doc="Convert the truth set from genome VCF format to a VCF\nbefore processing.")), ToolInput(tag="in_convert_gvc_f_query", input_type=Boolean(optional=True), prefix="--convert-gvcf-query", doc=InputDocumentation(doc="Convert the query set from genome VCF format to a VCF\nbefore processing.")), ToolInput(tag="in_preprocess_truth", input_type=Boolean(optional=True), prefix="--preprocess-truth", doc=InputDocumentation(doc="Preprocess truth file with same settings as query\n(default is to accept truth in original format).")), ToolInput(tag="in_use_filtered_truth", input_type=Boolean(optional=True), prefix="--usefiltered-truth", doc=InputDocumentation(doc="Use filtered variant calls in truth file (by default,\nonly PASS calls in the truth file are used)")), ToolInput(tag="in_preprocessing_window_size", input_type=Int(optional=True), prefix="--preprocessing-window-size", doc=InputDocumentation(doc="Preprocessing window size (variants further apart than\nthat size are not expected to interfere).")), ToolInput(tag="in_adjust_conf_regions", input_type=Boolean(optional=True), prefix="--adjust-conf-regions", doc=InputDocumentation(doc="Adjust confident regions to include variant locations.\nNote this will only include variants that are included\nin the CONF regions already when viewing with\nbcftools; this option only makes sure insertions are\npadded correctly in the CONF regions (to capture\nthese, both the base before and after must be\ncontained in the bed file).")), ToolInput(tag="in_no_adjust_conf_regions", input_type=Boolean(optional=True), prefix="--no-adjust-conf-regions", doc=InputDocumentation(doc="Do not adjust confident regions for insertions.")), ToolInput(tag="in_no_haplotype_comparison", input_type=Boolean(optional=True), prefix="--no-haplotype-comparison", doc=InputDocumentation(doc="Disable haplotype comparison (only count direct GT\nmatches as TP).")), ToolInput(tag="in_window_size", input_type=Int(optional=True), prefix="--window-size", doc=InputDocumentation(doc="Minimum distance between variants such that they fall\ninto the same superlocus.")), ToolInput(tag="in_x_cmp_enumeration_threshold", input_type=Int(optional=True), prefix="--xcmp-enumeration-threshold", doc=InputDocumentation(doc="Enumeration threshold / maximum number of sequences to\nenumerate per block.")), ToolInput(tag="in_x_cmp_expand_hap_blocks", input_type=String(optional=True), prefix="--xcmp-expand-hapblocks", doc=InputDocumentation(doc="Expand haplotype blocks by this many basepairs left\nand right.")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="Number of threads to use.")), ToolInput(tag="in_engine", input_type=String(optional=True), prefix="--engine", doc=InputDocumentation(doc="Comparison engine to use.")), ToolInput(tag="in_engine_vcf_eval_path", input_type=File(optional=True), prefix="--engine-vcfeval-path", doc=InputDocumentation(doc="This parameter should give the path to the 'rtg'\nexecutable. The default is rtg")), ToolInput(tag="in_engine_vcf_eval_template", input_type=File(optional=True), prefix="--engine-vcfeval-template", doc=InputDocumentation(doc="Vcfeval needs the reference sequence formatted in its\nown file format (SDF -- run rtg format -o ref.SDF\nref.fa). You can specify this here to save time when\nrunning hap.py with vcfeval. If no SDF folder is\nspecified, hap.py will create a temporary one.")), ToolInput(tag="in_scmp_distance", input_type=String(optional=True), prefix="--scmp-distance", doc=InputDocumentation(doc="For distance-based matching (vcfeval and scmp), this\nis the distance between variants to use.")), ToolInput(tag="in_lose_match_distance", input_type=String(optional=True), prefix="--lose-match-distance", doc=InputDocumentation(doc="For distance-based matching (vcfeval and scmp), this\nis the distance between variants to use.")), ToolInput(tag="in_log_file", input_type=File(optional=True), prefix="--logfile", doc=InputDocumentation(doc="Write logging information into file rather than to")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="Set logging level to output errors only.")), ToolInput(tag="in_v", input_type=Boolean(optional=True), prefix="-v", doc=InputDocumentation(doc="")), ToolInput(tag="in_stderr", input_type=String(), position=0, doc=InputDocumentation(doc="--verbose             Raise logging level from warning to info."))], outputs=[ToolOutput(tag="out_report_prefix", output_type=File(optional=True), selector=InputSelector(input_to_select="in_report_prefix", type_hint=File()), doc=OutputDocumentation(doc="Filename prefix for report output.")), ToolOutput(tag="out_keep_scratch", output_type=File(optional=True), selector=InputSelector(input_to_select="in_keep_scratch", type_hint=File()), doc=OutputDocumentation(doc="Filename prefix for scratch report output.")), ToolOutput(tag="out_no_json", output_type=File(optional=True), selector=InputSelector(input_to_select="in_no_json", type_hint=File()), doc=OutputDocumentation(doc="Disable JSON file output."))], container="quay.io/biocontainers/hap.py:0.3.14--py27h5c5a3ab_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Hap_Py_V0_1_0().translate("wdl")

